@@ -19,7 +19,7 @@ from pre_commit.util import cmd_output_b
 ENVIRONMENT_DIR = 'renv'
 RSCRIPT_OPTS = ('--no-save', '--no-restore', '--no-site-file', '--no-environ')
 get_default_version = helpers.basic_get_default_version
-healthy = helpers.basic_healthy
+health_check = helpers.basic_health_check
 
 
 def get_env_patch(venv: str) -> PatchesT:
